@@ -82,7 +82,7 @@ INDI is intended for developers seeking to add support for their devices in INDI
 </ul>
 <li>@ref Connection "INDI Connection Interface"</li>
 <li>@ref INDI::SP "INDI Standard Properties"</li>
-<li><a href="md_libs_indibase_alignment_alignment_white_paper.html">INDI Alignment Subsystem</a></li>
+<li><a href="md_libs_alignment_alignment_white_paper.html">INDI Alignment Subsystem</a></li>
 <li><a href="structINDI_1_1Logger.html">INDI Debugging & Logging API</a></li>
 <li>@ref DSP "Digital Signal Processing API"</li>
 <li><a href="indicom_8h.html">INDI Common Routine Library</a></li>
@@ -136,7 +136,7 @@ For a full list of contributors, please check <a href="https://github.com/indili
 /* INDI Library version */
 #define INDI_VERSION_MAJOR   2
 #define INDI_VERSION_MINOR   0
-#define INDI_VERSION_RELEASE 0
+#define INDI_VERSION_RELEASE 2
 
 /*******************************************************************************
  * Manifest constants
